Package: aelab
Type: Package
Title: Data Processing for Aquatic Ecology
Version: 1.1.3
Authors@R: person("Zhao-Jun", "Yong", role = c("cre","aut"), email = "nuannuan0425@gmail.com")
Maintainer: Zhao-Jun Yong <nuannuan0425@gmail.com>
Description: Facilitate the analysis of data related to aquatic ecology, specifically the establishment of carbon budget. 
  Currently, the package allows the below analysis.
  (i) the calculation of greenhouse gas flux based on data obtained from trace gas analyzer using the method described in Lin et al. (2024).
  (ii) the calculation of Dissolved Oxygen (DO) metabolism based on data obtained from dissolved oxygen data logger using the method described in Staehr et al. (2010). 
  Yong et al. (2024) <doi:10.5194/bg-21-5247-2024>.
  Staehr et al. (2010) <doi:10.4319/lom.2010.8.0628>.
Imports: tibble, lubridate, stats, dplyr, openxlsx, readxl, ggplot2,
        readr, tidyr, stringr, purrr, rlang, grDevices, multcompView,
        FSA, rcompanion, rnaturalearth, sf, ggspatial
License: GPL (>= 3)
Encoding: UTF-8
RoxygenNote: 7.2.3
Suggests: knitr, rmarkdown, testthat (>= 3.0.0), rnaturalearthdata
Config/testthat/edition: 3
Depends: R (>= 4.1.0)
VignetteBuilder: knitr
LazyData: true
NeedsCompilation: no
Packaged: 2026-05-07 08:44:52 UTC; yangshaojun
Author: Zhao-Jun Yong [cre, aut]
Repository: CRAN
Date/Publication: 2026-05-07 12:10:44 UTC
Built: R 4.5.2; ; 2026-05-07 13:42:04 UTC; unix
