# Generated by roxygen2: do not edit by hand

export(aelab_palettes)
export(aov_test)
export(calc_chla_trichromatic)
export(calculate_MDF)
export(calculate_do)
export(calculate_ghg_flux)
export(calculate_regression)
export(calculate_total_co2e)
export(combine_hobo)
export(combine_weather)
export(combine_weather_month)
export(convert_ghg_unit)
export(convert_time)
export(descriptive_statistic)
export(df_trans)
export(find_outlier)
export(ks_test)
export(normality_test_aov)
export(normality_test_t)
export(plot_bar)
export(plot_box)
export(plot_hobo)
export(plot_line)
export(plot_map_taiwan)
export(plot_point)
export(process_hobo)
export(process_info)
export(process_weather)
export(process_weather_month)
export(scale_color_aelab_c)
export(scale_color_aelab_d)
export(scale_colour_aelab_c)
export(scale_colour_aelab_d)
export(scale_fill_aelab_c)
export(scale_fill_aelab_d)
export(sig_labels)
export(tidy_ghg_analyzer)
import(ggplot2)
import(tibble)
importFrom(FSA,dunnTest)
importFrom(dplyr,across)
importFrom(dplyr,arrange)
importFrom(dplyr,bind_rows)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,mutate)
importFrom(dplyr,select)
importFrom(dplyr,summarise)
importFrom(dplyr,where)
importFrom(ggspatial,annotation_north_arrow)
importFrom(ggspatial,annotation_scale)
importFrom(ggspatial,north_arrow_fancy_orienteering)
importFrom(grDevices,colorRampPalette)
importFrom(lubridate,as_datetime)
importFrom(lubridate,ceiling_date)
importFrom(lubridate,days)
importFrom(lubridate,force_tz)
importFrom(lubridate,hours)
importFrom(lubridate,minutes)
importFrom(lubridate,seconds)
importFrom(lubridate,ymd_hms)
importFrom(multcompView,multcompLetters4)
importFrom(openxlsx,convertToDateTime)
importFrom(purrr,map_df)
importFrom(purrr,map_dfr)
importFrom(rcompanion,cldList)
importFrom(readr,read_csv)
importFrom(readxl,read_excel)
importFrom(rlang,"!!")
importFrom(rlang,sym)
importFrom(rnaturalearth,ne_countries)
importFrom(sf,st_as_sf)
importFrom(stats,TukeyHSD)
importFrom(stats,aggregate)
importFrom(stats,aov)
importFrom(stats,as.formula)
importFrom(stats,coef)
importFrom(stats,kruskal.test)
importFrom(stats,lm)
importFrom(stats,na.omit)
importFrom(stats,quantile)
importFrom(stats,shapiro.test)
importFrom(stats,time)
importFrom(stringr,str_detect)
importFrom(stringr,str_remove)
importFrom(stringr,str_replace)
importFrom(tibble,tibble)
importFrom(tidyr,fill)
importFrom(utils,read.csv)
